#------------------------------------------------------------------------------
# copylog.sh - copy or move files on shutdown
#
# Creation:	21.10.2001 Peter Schiefer mailto:lanspezi@lan4me.de
# Last Update:  27.02.2003 Peter Schiefer 
#------------------------------------------------------------------------------
if [ "$COPYLOG_DO_DEBUG" = yes ]
then
	set -x
fi

. /var/run/copylog.conf

if [ "$OPT_COPYLOG" = "yes" ]
then
  if [ -d $COPYLOG_ARCHIVE ]
  then
    cppath=$COPYLOG_ARCHIVE/copylog$(date +%Y%m%d-%H%M)
    /usr/local/bin/copylog_echo.sh "copylog" "Files are archived to $cppath"
    
    idx=1
    while [ "$idx" -le "$COPYLOG_N" ]
    do
      eval quell='$COPYLOG_'$idx'_QUELL'
      eval art='$COPYLOG_'$idx'_ART'
      eval custom='$COPYLOG_'$idx'_CUSTOM'

      if [ -f "$quell" ]
      then
        if [ "$art" = "move" ]
        then
          if [ ! -d $cppath ]
          then
            /bin/mkdir $cppath
          fi
          /bin/cp $quell $cppath
          > $quell
          /usr/local/bin/copylog_echo.sh "copylog" "$quell moved ..."
        fi
        if [ "$art" = "copy" ]
        then
          if [ ! -d $cppath ]
          then
            /bin/mkdir $cppath
          fi
          cp $quell $cppath
          /usr/local/bin/copylog_echo.sh "copylog" "$quell copied ..."
        fi
        if [ "$art" = "delete" ]
        then
          /bin/rm $quell
          > $quell
          /usr/local/bin/copylog_echo.sh "copylog" "$quell deleted ..."
        fi

        if [ "$custom" != "" ]
        then
          $custom
          /usr/local/bin/copylog_echo.sh "copylog" "execute $custom"
        fi
      fi
      
      idx=`/usr/bin/expr $idx + 1`
    done
    
    # pruefen der anzahl der logs
    if [ "$COPYLOG_ARCHIVE_MAXANZ" != "0" ]
    then
      anzahl=0
      for j in $COPYLOG_ARCHIVE/copylog*
      do
        anzahl=`/usr/bin/expr $anzahl + 1`
      done
      if [ "$anzahl" -ge "$COPYLOG_ARCHIVE_MAXANZ" ]
      then
        /usr/local/bin/copylog_echo.sh "copylog" "max. count of copylogs reached"
      fi
      while [ "$anzahl" -ge "$COPYLOG_ARCHIVE_MAXANZ" ]
      do
        set -- $COPYLOG_ARCHIVE/copylog*
        rmpath=$1
        /bin/rm -r $rmpath
        /usr/local/bin/copylog_echo.sh "copylog" "$rmpath removed ..."
        anzahl=`/usr/bin/expr $anzahl - 1`
      done
    fi

  else
    /usr/local/bin/copylog_echo.sh "copylog" "ERROR - COPYLOG_ARCHIVE not exist"
  fi
fi

/bin/sleep 10

set +x